@@ -2,7 +2,7 @@ package HTTP::MobileAgent::Plugin::SmartPhone;
 use strict;
 use warnings;
 use utf8;
-our $VERSION = '0.021';
+our $VERSION = '0.03';
 
 sub HTTP::MobileAgent::is_smartphone {
     my $self = shift;
@@ -11,23 +11,37 @@ sub HTTP::MobileAgent::is_smartphone {
 
 sub HTTP::MobileAgent::is_ios {
     my $self = shift;
-    $self->user_agent =~ /\(iP(?:hone|od|ad)/;
+
+    my $ua = $self->user_agent || '';
+    $ua =~ /\(iP(?:hone|od|ad)/;
 }
 
 sub HTTP::MobileAgent::is_iphone {
-    shift->user_agent =~ /\(iPhone/;
+    my $self = shift;
+
+    my $ua = $self->user_agent || '';
+    $ua =~ /\(iPhone/;
 }
 
 sub HTTP::MobileAgent::is_ipad {
-    shift->user_agent =~ /\(iPad/;
+    my $self = shift;
+
+    my $ua = $self->user_agent || '';
+    $ua =~ /\(iPad/;
 }
 
 sub HTTP::MobileAgent::is_ipod {
-    shift->user_agent =~ /\(iPod/;
+    my $self = shift;
+
+    my $ua = $self->user_agent || '';
+    $ua =~ /\(iPod/;
 }
 
 sub HTTP::MobileAgent::is_android {
-    shift->user_agent =~ /Android/;
+    my $self = shift;
+
+    my $ua = $self->user_agent || '';
+    $ua =~ /Android/;
 }
 
 sub HTTP::MobileAgent::is_android_tablet {
